#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
import os
import requests

from bangumi import api_endpoints
from bangumi.api_endpoints import USER_CURRENT
from requests.adapters import HTTPAdapter
from urllib3.util.retry import Retry

class BangumiClient:
    def __init__(self):
        self.token = os.getenv("BGM_ACCESS_TOKEN")
        if not self.token:
            raise ValueError("BGM_ACCESS_TOKEN environment variable is not set.")
        self.session = self._get_retry_session()
        self.session.headers.update({
            "Authorization": f"Bearer {self.token}",
            "User-Agent": f"bGZo/self-debug-private-project"
        })
        self.api_endpoints = api_endpoints

    def _get_retry_session(self, retries=10, backoff_factor=0.3, timeout=30):
        session = requests.Session()
        retry = Retry(
            total=retries,
            read=retries,
            connect=retries,
            backoff_factor=backoff_factor,
            status_forcelist=(500, 502, 504),
            allowed_methods=frozenset(['GET', 'POST']),
            raise_on_status=False
        )
        adapter = HTTPAdapter(max_retries=retry)
        session.mount('http://', adapter)
        session.mount('https://', adapter)
        # 给 session 增加默认超时
        session.request = self._wrap_request_with_timeout(session.request, timeout)
        return session

    def _wrap_request_with_timeout(self, func, timeout):
        def wrapper(*args, **kwargs):
            if 'timeout' not in kwargs:
                kwargs['timeout'] = timeout
            return func(*args, **kwargs)
        return wrapper

    def get_user(self):
        resp = self.session.get(USER_CURRENT)
        return resp.json()



from dataclasses import dataclass
from typing import List, Optional, Any, Dict

@dataclass
class Paging:
    is_end: bool
    is_start: bool
    next: str
    previous: str
    totals: int

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Paging':
        return Paging(
            is_end=data.get("is_end", False),
            is_start=data.get("is_start", False),
            next=data.get("next", ""),
            previous=data.get("previous", ""),
            totals=data.get("totals", 0)
        )

@dataclass
class Question:
    id: str
    title: str
    url: str
    type: str
    created: int
    updated_time: int

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Question':
        return Question(
            id=str(data.get("id", "")),
            title=data.get("title", ""),
            url=data.get("url", ""),
            type=data.get("type", ""),
            created=data.get("created", 0),
            updated_time=data.get("updated_time", 0)
        )

@dataclass
class Author:
    id: str
    name: str
    url_token: str
    headline: str
    url: str

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Author':
        return Author(
            id=data.get("id", ""),
            name=data.get("name", ""),
            url_token=data.get("url_token", ""),
            headline=data.get("headline", ""),
            url=data.get("url", "")
        )

@dataclass
class Content:
    id: str
    type: str
    url: str
    content: str
    voteup_count: int
    comment_count: int
    created_time: int
    updated_time: int
    author: Optional[Author] = None
    question: Optional[Question] = None
    title: Optional[str] = None

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Content':
        return Content(
            id=str(data.get("id", "")),
            type=data.get("type", ""),
            url=data.get("url", ""),
            content=data.get("content", ""),
            voteup_count=data.get("voteup_count", 0),
            comment_count=data.get("comment_count", 0),
            created_time=data.get("created_time", 0),
            updated_time=data.get("updated_time", 0),
            author=Author.from_dict(data.get("author")) if data.get("author") else None,
            question=Question.from_dict(data.get("question")) if data.get("question") else None,
            title=data.get("title")
        )

@dataclass
class CollectionItem:
    content: Content
    created: str

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'CollectionItem':
        return CollectionItem(
            content=Content.from_dict(data.get("content", {})),
            created=data.get("created", "")
        )

@dataclass
class CollectionResponse:
    paging: Paging
    data: List[CollectionItem]

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'CollectionResponse':
        return CollectionResponse(
            paging=Paging.from_dict(data.get("paging", {})),
            data=[CollectionItem.from_dict(item) for item in data.get("data", [])]
        )




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
因为API没有提供这个接口，所以只能通过解析HTML来实现获取我的主题列表功能，进度参考：

https://www.v2ex.com/t/1035675

总体希望不大

@Author : bGZo
@Date : 2025-12-13
@Links : https://github.com/bGZo
"""
from bs4 import BeautifulSoup

from v2ex.cilent import V2exClient
from v2ex.api_endpoints import V2EX_FAV


def get_fav_html_with_page(page: int) -> str:
    """
    获取我的主题页面的HTML内容

    :param page: 页码
    :return: HTML内容字符串
    """
    client = V2exClient()
    response = client.session.get(V2EX_FAV, params={"p": page})
    return response.text


def get_fav_list_topic_id_page(page: int) -> list[int]:
    """
    获取我的主题页面的主题ID列表

    :param page: 页码
    :return: 主题ID列表
    """
    fav_html = get_fav_html_with_page(page)
    soup = BeautifulSoup(fav_html, 'html.parser')
    topic_id_list = []
    for topic_link in soup.select('a[href^="/t/"]'):
        href = topic_link.get('href')
        if href:
            try:
                topic_id = int(href.split('/t/')[1].split('#')[0])
                topic_id_list.append(topic_id)
            except ValueError:
                continue
    return list(set(topic_id_list))


if __name__ == '__main__':
    page = 1
    # fav_html = get_fav_html_with_page(page)
    # print(fav_html)
    topic_ids = get_fav_list_topic_id_page(page)
    print(topic_ids)



from dataclasses import dataclass
from typing import List, Optional, Any

@dataclass
class Origin:
    feedId: Optional[str] = None

    @staticmethod
    def from_dict(data: dict) -> 'Origin':
        return Origin(feedId=data.get("feedId"))

@dataclass
class Entry:
    id: str
    isSaved: bool
    sourceEntryId: str
    origin: Optional[Origin]
    title: str
    summary: str
    url: str
    publishedAt: int
    crawledAt: int
    timestamp: str
    attachments: List[Any]
    tagIds: List[str]

    @staticmethod
    def from_dict(data: dict) -> 'Entry':
        return Entry(
            id=data.get("id"),
            isSaved=data.get("isSaved"),
            sourceEntryId=data.get("sourceEntryId"),
            origin=Origin.from_dict(data.get("origin")) if data.get("origin") else None,
            title=data.get("title"),
            summary=data.get("summary"),
            url=data.get("url"),
            publishedAt=data.get("publishedAt"),
            crawledAt=data.get("crawledAt"),
            timestamp=data.get("timestamp"),
            attachments=data.get("attachments", []),
            tagIds=data.get("tagIds", [])
        )

@dataclass
class StreamResult:
    id: str
    entries: List[Entry]
    hasMore: bool

    @staticmethod
    def from_dict(data: dict) -> 'StreamResult':
        return StreamResult(
            id=data.get("id"),
            entries=[Entry.from_dict(e) for e in data.get("entries", [])],
            hasMore=data.get("hasMore")
        )

@dataclass
class QiReaderResponse:
    result: StreamResult

    @staticmethod
    def from_dict(data: dict) -> 'QiReaderResponse':
        return QiReaderResponse(
            result=StreamResult.from_dict(data.get("result", {}))
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-06
@Links : https://github.com/bGZo
"""
import os

import requests

from demo import (api_endpoints)

class ZhihuClient:
    def __init__(self):
        self.cookie = os.getenv("ZHIHU_COOKIE")

        if not self.cookie:
            raise ValueError("ZHIHU_COOKIE environment variable is not set.")
        self.session = requests.Session()
        self.session.headers.update({
            # "Authorization": f"Bearer {self.token}",
            "Cookie": f"{self.cookie}",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:144.0) Gecko/20100101 Firefox/144.0",
            "Referer": "https://www.zhihu.com"
        })
        self.api_endpoints = api_endpoints



from dataclasses import dataclass
from typing import List, Optional, Any, Dict

@dataclass
class Member:
    id: int
    username: str
    bio: str
    website: str
    github: str
    url: str
    avatar: str
    created: int
    pro: Optional[int] = None

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Member':
        return Member(
            id=data.get("id", 0),
            username=data.get("username", ""),
            bio=data.get("bio", ""),
            website=data.get("website", ""),
            github=data.get("github", ""),
            url=data.get("url", ""),
            avatar=data.get("avatar", ""),
            created=data.get("created", 0),
            pro=data.get("pro")
        )

@dataclass
class Node:
    id: int
    url: str
    name: str
    title: str
    header: str
    footer: str
    avatar: str
    topics: int
    created: int
    last_modified: int

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'Node':
        return Node(
            id=data.get("id", 0),
            url=data.get("url", ""),
            name=data.get("name", ""),
            title=data.get("title", ""),
            header=data.get("header", ""),
            footer=data.get("footer", ""),
            avatar=data.get("avatar", ""),
            topics=data.get("topics", 0),
            created=data.get("created", 0),
            last_modified=data.get("last_modified", 0)
        )

@dataclass
class TopicResult:
    id: int
    title: str
    content: str
    syntax: int
    url: str
    replies: int
    last_reply_by: str
    created: int
    last_modified: int
    last_touched: int
    member: Optional[Member]
    node: Optional[Node]
    supplements: List[Any]

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'TopicResult':
        return TopicResult(
            id=data.get("id", 0),
            title=data.get("title", ""),
            content=data.get("content", ""),
            syntax=data.get("syntax", 0),
            url=data.get("url", ""),
            replies=data.get("replies", 0),
            last_reply_by=data.get("last_reply_by", ""),
            created=data.get("created", 0),
            last_modified=data.get("last_modified", 0),
            last_touched=data.get("last_touched", 0),
            member=Member.from_dict(data.get("member")) if data.get("member") else None,
            node=Node.from_dict(data.get("node")) if data.get("node") else None,
            supplements=data.get("supplements", [])
        )

@dataclass
class TopicResponse:
    success: bool
    message: str
    result: Optional[TopicResult]

    @staticmethod
    def from_dict(data: Dict[str, Any]) -> 'TopicResponse':
        return TopicResponse(
            success=data.get("success", False),
            message=data.get("message", ""),
            result=TopicResult.from_dict(data.get("result")) if data.get("result") else None
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-13
@Links : https://github.com/bGZo
"""
from typing import Optional
from v2ex.api_endpoints import V2EX_API_TOPICS
from v2ex.cilent import V2exClient
from v2ex.entity import TopicResponse


def get_v2ex_topic_info(topic_id: int) -> Optional[TopicResponse]:
    client = V2exClient()
    response = client.session.get(V2EX_API_TOPICS.format(topic_id=topic_id))
    
    if response.status_code == 200:
        return TopicResponse.from_dict(response.json())
    return None
    
if __name__ == '__main__':
    test_topic_id = "1"
    topic_info = get_v2ex_topic_info(test_topic_id)
    print(topic_info)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""

def get_cnblog_post_body_by_url(url: str):
    """
    获取指定 ID 的博客文章正文内容。

    :param id: 博客文章的 ID
    :return: 博客文章正文内容
    """
    from cnblog.client import CnblogClient
    from cnblog.api_endpoints import BLOG_POST

    client = CnblogClient()

    # 从 URL 中提取 ID，并去除 .html 后缀
    id = url.split('/')[-1]
    # NOTE: 这里假设 URL 的最后一部分是 ID，且可能以 .html 结尾。如：
    #  https://api.cnblogs.com/api/blogposts/755751.html/body
    if id.endswith('.html'):
        id = id[:-5]

    response = client.session.get(BLOG_POST % id)
    # % 是 Python 早期的字符串格式化操作符。它会查找字符串中的 % 占位符（如 %s），并用后面的值替换它。

    if response.status_code == 200:
        return response.text
    else:
        print(f"Error fetching post body for ID {id}: {response.status_code}")
        return ""
        # response.raise_for_status()  # Raise an error for bad responses



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-06
@Links : https://github.com/bGZo
"""
from typing import List, Optional
from charset_normalizer import from_fp

from qireader.cilent import QiReaderClient
from qireader.models import QiReaderResponse, Entry


def get_list_from_read_latter(tag_id: str, oldThan: Optional[str]) -> List[Entry]:
    """
    target-url: https://www.qireader.com/api/streams/{tagId}?articleOrder=0&count=25&id={tagId}&unreadOnly=false&olderThan=1764313764608411573

    :param tag-xxx
    """
    client = QiReaderClient()
    response = client.session.get(client.api_endpoints.READ_LATER + tag_id,  params={
        'articleOrder': 0,
        'count': 25,
        'id': tag_id,
        'unreadOnly': "False",
        'olderThan': oldThan
    })
    
    if response.status_code == 200:
        return QiReaderResponse.from_dict(response.json()).result.entries
    return []


def get_all_list_from_read_latter_debug(tag_id: str) -> List[Entry]:
    all_entries = []
    older_than = None

    while True:
        entries = get_list_from_read_latter(tag_id, older_than)
        if not entries:
            break
        all_entries.extend(entries)
        older_than = str(entries[-1].timestamp)

    return all_entries

if __name__ == '__main__':
    try:
        bookmarks = get_list_from_read_latter("tag-xxx", None)
        # bookmarks = get_all_list_from_read_latter("tag-Jw3lnV59k7Vaky2g")
        print(bookmarks)
    except Exception as e:
        print(f"An error occurred: {e}")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-13
@Links : https://github.com/bGZo
"""
from zhihu.api_endpoints import FAV_URL
from zhihu.cilent import ZhihuClient
from zhihu.entity import CollectionResponse


def get_collection_page(collection_id: str, offset: int, limit: int) -> CollectionResponse:
    zhihuClient = ZhihuClient()

    res = zhihuClient.session.get(FAV_URL.format(collection_id=collection_id), params={
        'offset': offset,
        'limit': limit
    })
    
    if res.status_code == 200:
        return CollectionResponse.from_dict(res.json())
    return None

if __name__ == '__main__':
    collection_id = "908297073"
    offset = 0
    limit = 20

    collection_page = get_collection_page(collection_id, offset, limit)
    print(collection_page)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-08-18
@Links : https://github.com/bGZo
"""
from bangumi.api_endpoints import SUBJECT_QUERY, SUBJECT_CHARACTER_QUERY
from bangumi.client import BangumiClient
from bangumi.entity import SubjectV0, SubjectImages, SubjectTag, V0wiki, Rating, SubjectCollectionStat, SubjectRelatedCharacter, PersonImages, Actor


def get_subject_info(subject_id: int) -> SubjectV0:
    client = BangumiClient()
    res = client.session.get(
        SUBJECT_QUERY % subject_id
    )
    if res.status_code == 200:
        result = res.json()
        return _dict_to_subject(result)
    else:
        print(f"Error fetching {subject_id} info with response: {res.status_code} {res[res.status_code]}")
        return None

def _dict_to_subject(data: dict) -> SubjectV0:
    images = SubjectImages(**data.get('images', {})) if data.get('images') else None
    tags = [SubjectTag(**tag) for tag in data.get('tags', [])]
    # infobox: List[Any]，此处直接传递原始list
    infobox = data.get('infobox', None)
    rating_data = data.get('rating', None)
    rating = None
    if rating_data:
        # rating.count 可能是 dict，需特殊处理
        count = rating_data.get('count')
        if isinstance(count, dict):
            # 直接存原始dict
            rating = Rating(
                rank=rating_data.get('rank'),
                total=rating_data.get('total'),
                count=count,
                score=rating_data.get('score')
            )
        else:
            rating = Rating(**rating_data)
    collection_data = data.get('collection', None)
    collection = None
    if collection_data:
        collection = SubjectCollectionStat(
            wish=collection_data.get('wish', 0),
            collect=collection_data.get('collect', 0),
            doing=collection_data.get('doing', 0),
            on_hold=collection_data.get('on_hold', 0),
            dropped=collection_data.get('dropped', 0),
            total=collection_data.get('total', 0)
        )
    return SubjectV0(
        date=data.get('date'),
        platform=data.get('platform'),
        images=images,
        summary=data.get('summary', ''),
        name=data.get('name', ''),
        name_cn=data.get('name_cn', ''),
        tags=tags,
        infobox=infobox,
        rating=rating,
        total_episodes=data.get('total_episodes', 0),
        collection=collection,
        id=data.get('id', 0),
        eps=data.get('eps', 0),
        meta_tags=data.get('meta_tags', []),
        volumes=data.get('volumes', 0),
        series=data.get('series', False),
        locked=data.get('locked', False),
        nsfw=data.get('nsfw', False),
        type_id=data.get('type', 0),
        redirect=data.get('redirect')
    )

def _dict_to_subject_character(data: dict) -> SubjectRelatedCharacter:
    # 兼容 images 字段缺失 key 的情况
    images_data = data.get('images', {})
    images = PersonImages(
        small=images_data.get('small', ''),
        grid=images_data.get('grid', ''),
        large=images_data.get('large', ''),
        medium=images_data.get('medium', ''),
        common=images_data.get('common', '')
    ) if images_data else None
    actors = []
    for actor in data.get('actors', []):
        actor_images_data = actor.get('images', {})
        actor_images = PersonImages(
            small=actor_images_data.get('small', ''),
            grid=actor_images_data.get('grid', ''),
            large=actor_images_data.get('large', ''),
            medium=actor_images_data.get('medium', ''),
            common=actor_images_data.get('common', '')
        ) if actor_images_data else None
        actors.append(
            Actor(
                id=actor.get('id'),
                name=actor.get('name', ''),
                images=actor_images,
                short_summary=actor.get('short_summary', ''),
                career=actor.get('career', []) or [],
                type=actor.get('type', 0),
                locked=actor.get('locked', False)
            )
        )
    return SubjectRelatedCharacter(
        images=images,
        name=data.get('name', ''),
        relation=data.get('relation', ''),
        actors=actors,
        type=data.get('type', 0),
        id=data.get('id', 0)
    )

def get_subject_character(subject_id: int) -> list[SubjectRelatedCharacter]:
    client = BangumiClient()
    res = client.session.get(
        SUBJECT_CHARACTER_QUERY % subject_id
    )
    if res.status_code == 200:
        result = res.json()
        return [_dict_to_subject_character(item) for item in result]
    else:
        print(f"Error fetching character of {subject} with response: {res.status_code} {res[res.status_code]}")
        return []



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
from cnblog.client import CnblogClient
from dataclasses import dataclass
from typing import List, Any

@dataclass
class Bookmark:
    WzLinkId: int
    Title: str
    LinkUrl: str
    Summary: str
    Tags: List[Any]
    DateAdded: str
    FromCNBlogs: bool

    @staticmethod
    def from_dict(data: dict) -> "Bookmark":
        return Bookmark(
            WzLinkId=data.get("WzLinkId"),
            Title=data.get("Title"),
            LinkUrl=data.get("LinkUrl"),
            Summary=data.get("Summary"),
            Tags=data.get("Tags", []),
            DateAdded=data.get("DateAdded"),
            FromCNBlogs=data.get("FromCNBlogs"),
        )

def get_bookmark_list(page_index: int, page_size: int) -> list:
    """
    Fetches the list of bookmarks from the CNBlog API.

    Returns:
        list: A list of bookmarks.
    """
    client = CnblogClient()
    response = client.session.get(client.api_endpoints.BOOKMARK, params={
        'pageIndex': page_index,
        'pageSize': page_size
    })
    if response.status_code == 200:
        data = response.json()
        # 支持单个对象或对象列表
        if isinstance(data, dict):
            return [Bookmark.from_dict(data)]
        return [Bookmark.from_dict(item) for item in data]
    else:
        # Raise an error for bad responses
        response.raise_for_status()

# TODO 好像没有办法处理事务...
def delete_by_id(id: int):
    """
    Deletes a bookmark by its ID.

    Args:
        id (int): The ID of the bookmark to delete.
    """
    client = CnblogClient()
    response = client.session.delete(f"{client.api_endpoints.BOOKMARK_DELETE}/{id}")
    if response.status_code == 204:
        print(f"Bookmark with ID {id} deleted successfully.")
    else:
        response.raise_for_status()  # Raise an error for bad responses

if __name__ == '__main__':
    try:
        bookmarks = get_bookmark_list()
        for bm in bookmarks:
            print(bm.Title, bm.LinkUrl)
    except Exception as e:
        print(f"An error occurred: {e}")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-06
@Links : https://github.com/bGZo
"""

V2EX_FAV = "https://www.v2ex.com/my/topics"

V2EX_API_TOPICS = "https://www.v2ex.com/api/v2/topics/{topic_id}"


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
import os
import requests

from cnblog import api_endpoints
from cnblog.api_endpoints import USER

class CnblogClient:
    def __init__(self):
        self.token = os.getenv("CNBLOG_ACCESS_TOKEN")
        if not self.token:
            raise ValueError("CNBLOG_ACCESS_TOKEN environment variable is not set.")
        self.session = requests.Session()
        self.session.headers.update({
            "Authorization": f"Bearer {self.token}"
        })
        self.api_endpoints = api_endpoints

    def get_user(self):
        resp = self.session.get(USER)
        return resp.json()



from pickle import FALSE

import click
import os

from bangumi.client import BangumiClient
from bangumi.collection import get_all_collections_by_pages
from bangumi.enum import SubjectType, CollectionType
from cnblog.blog_post import get_cnblog_post_body_by_url
from cnblog.bookmark import get_bookmark_list
from qireader.getext import get_html_text_from_url
from utils.file_utils import output_content_to_file_path, get_clean_filename
from utils.md_utils import html_to_markdown_with_html2text, html_to_markdown_with_bs
from utils.template import WebPage
from utils.md_utils import dump_markdown_with_frontmatter
from bangumi.subject import get_subject_info, get_subject_character
from datetime import datetime

from v2ex.mytopic import get_fav_list_topic_id_page
from v2ex.topic import get_v2ex_topic_info
from zhihu.collection import get_collection_page


# CNBLOG 博客园
def cnblog_export(output_dir):
    page_index = 1
    page_size = 100
    result_index = ""
    while True:
        bookmarks = get_bookmark_list(page_index, page_size)
        if not bookmarks:
            break
        for bm in bookmarks:
            filename = get_clean_filename(bm.Title)
            file_path = os.path.join(output_dir, f"~{filename}.md")
            if os.path.exists(file_path):
                print(f"已存在，提前结束: {filename}.md")
                print("输出index:\n", result_index)
                return  # 剪枝，提前退出
            if bm.FromCNBlogs:
                webpage = WebPage(
                    comments=True,
                    draft=True,
                    title=bm.Title,
                    source=bm.LinkUrl,
                    created=bm.DateAdded,
                    modified=bm.DateAdded,
                    type="archive-web"
                )

                md = dump_markdown_with_frontmatter(
                    webpage.__dict__,
                    html_to_markdown_with_bs(
                        get_cnblog_post_body_by_url(bm.LinkUrl)
                    )
                )
                output_content_to_file_path(
                    output_dir,
                    filename,
                    md,
                    "md")

                print(f"Done: {bm.Title}")
            else:
                print(f"Skip: {bm.Title}")
            result_index += f'\n- [[~{filename}|{bm.Title}]]'
        page_index += 1
    print("输出index:\n", result_index)

def bangumi_export(subject_type: int, collection_type: int, output_dir: str, template_path: str, force: bool = False):
    client = BangumiClient()
    username = client.get_user()['username']
    limit = 30
    offset = 0
    result_index = ""

    while True:
        results = get_all_collections_by_pages(
            username,
            subject_type,
            collection_type,
            limit=limit,
            offset=offset
        )
        if not results:
            break
        if len(results) == 0:
            break
        offset += limit
        for res in results:
            # print("get response=", res)
            try:
                result, filename, title = write_bangumi_data_from_id(
                    subject_id=res.subject_id,
                    collection_type=collection_type,
                    output_dir=output_dir,
                    template_path=template_path,
                    force=force)
                if result:
                    result_index += f'\n- [[{filename}|{title}]]'
                elif not force:
                    print(f"写入失败: {filename}")
                    print("输出index\n", result_index)
                    return
            except Exception as e:
                print(f"跳过:{res.subject.name}, subject_id={res.subject_id}, error={e}")
            print(f"处理完成={res.subject_id}")
    print("输出index\n", result_index)


def write_bangumi_data_from_id(subject_id: int, collection_type: int, output_dir: str, template_path: str, force: bool = False) -> (bool, str, str):
    # 1. 获取条目详情
    subject = get_subject_info(subject_id)
    if not subject:
        print(f"未获取到条目详情: {subject_id}")
        # 当前条目可能有问题，不能影响后续的导出执行，需要跳过
        return True, '', ''

    subject_type = subject.type_id
    subject_type_en = SubjectType.get_name_en(subject_type)
    collection_type_en = CollectionType.get_name_en(collection_type)
    tags = ['bangumi/'+collection_type_en, 'bangumi/' + subject_type_en]
    # 处理别名
    aliases_set = { subject.name }
    website_set = set() # {}
    if subject.name_cn:
        aliases_set.add(subject.name_cn)
    # if subject.infobox:
    #     for item in subject.infobox:
    #         if item['key'] == '别名':
    #             for v in item['value']:
    #                 if v['v'] != '':
    #                     aliases_set.add(v['v'])

    if subject.infobox:
        for item in subject.infobox:
            # 添加官方网站1
            website_set.update(
                parse_infobox_value(item) if item.get("key") == "官方网站" else []
            )
            # 添加官方网站2
            website_set.update(
                parse_infobox_value(item) if item.get("key") == "website" else []
            )
            # 更新别名
            aliases_set.update(
                parse_infobox_value(item) if item.get("key") == "别名" else []
            )
    created_date = (subject.date or datetime.now().strftime('%Y-%m-%d')) + datetime.now().strftime('T%H:%M:%S%z')
    filename = str(subject_id) + "-" + get_clean_filename(subject.name_cn or subject.name or str(subject.id)) + '.md'
    output_path = os.path.join(output_dir, subject_type_en, filename)
    if os.path.exists(output_path) and not force:
        print(f"已存在，提前结束: {filename}")
        return False, '', ''

    # 2. 读取模板内容
    with open(template_path, 'r', encoding='utf-8') as f:
        template = f.read()

    # 3. 渲染模板（这里只做简单替换，可根据需要扩展）
    # 你可以根据模板变量名和 subject 字段进行映射
    content = template
    title = subject.name_cn or subject.name or ""
    content = content.replace('{{tags}}', str(tags))
    content = content.replace('{{aliases}}', str(list(aliases_set)))
    content = content.replace('{{website}}', str(list(website_set)))
    content = content.replace('{{title}}', title)
    content = content.replace('{{bangumi}}', str(subject.id))
    content = content.replace('{{cover}}', subject.images.medium if subject.images else "")
    content = content.replace('{{created}}', created_date)
    content = content.replace('{{modified}}', datetime.now().strftime('%Y-%m-%dT%H:%M:%S%z'))
    content = content.replace('{{rating}}', str(subject.rating.score) if subject.rating and subject.rating.score else "")
    content = content.replace('{{type}}', 'bangumi/' + subject_type_en)
    content = content.replace('{{characters}}', get_output_character_string(subject_id))
    content = content.replace('{{summary}}', subject.summary or "")

    # 4. 写入文件
    os.makedirs(os.path.dirname(output_path), exist_ok=True)
    # utils.file_utils.ensure_output_directory_exists()
    with open(output_path, 'w', encoding='utf-8') as f:
        f.write(content)
    print(f"写入完成: {output_path}")
    return True, filename, title


def parse_infobox_value(item):
    value = item.get("value")
    if isinstance(value, str):
        # 直接返回字符串
        return [value]
    elif isinstance(value, list):
        # 提取每个字典的 'v' 字段
        return [v.get("v") for v in value if isinstance(v, dict) and "v" in v]
    else:
        # 其他类型，返回空列表或自定义处理
        return []

def get_output_character_string(subject_id: int) -> str:
    result = ""
    character_template = """### {}:{}

![]({})"""
    character_list = get_subject_character(subject_id)
    for character in character_list:
        if result != '':
            result += '\n\n'
        result += character_template.format(
            character.name,
            character.relation,
            character.images.medium if character.images else ""
        )

    return  result

@click.group()
def eto():
    pass

@eto.command()
@click.option('--output', '-o', required=True, help='输出目录')
def cnblog(output):
    cnblog_export(output)

@eto.command()
@click.option('--template', '-t', required=True, type=str, help='模板文件')
@click.option('--subject_type', '-s', required=True, type=int, help='主题类型')
@click.option('--output', '-o', required=True, help='输出目录')
@click.option('--collection_type', '-c', required=False, type=int, help='收藏类型')
@click.option('--force', required=False, is_flag=True, help='是否强制覆盖')
def bangumi(subject_type, collection_type, output, template, force):
    if collection_type:
        bangumi_export(subject_type, collection_type, output, template, force)
    else:
        sync_all_collection_under_subject_type(subject_type, output, template, force)

@eto.command()
@click.option('--tag', '-t', required=True, type=str, help='收藏夹ID')
@click.option('--output', '-o', required=True, help='输出目录')
def qireader(tag, output):
    from qireader.readlatter import get_list_from_read_latter
    older_than = None
    result_index = "";

    while True:
        entries = get_list_from_read_latter(tag, older_than)
        if not entries:
            break

        for entry in entries:
            filename = get_clean_filename(entry.title)
            file_path = os.path.join(output, f"~{filename}.md")
            if os.path.exists(file_path):
                print(f"已存在: {filename}.md，同步结束")
                print("导出index\n", result_index)
                return

            timestamp_seconds = int(entry.timestamp) / 1_000_000_000
            webpage = WebPage(
                comments=True,
                draft=True,
                title=entry.title,
                source=entry.url,
                created=datetime.fromtimestamp(timestamp_seconds).strftime('%Y-%m-%dT%H:%M:%S%z'),
                modified=datetime.fromtimestamp(timestamp_seconds).strftime('%Y-%m-%dT%H:%M:%S%z'),
                type="archive-web"
            )
            # 尝试获取内容
            content = ''
            try:
                content = html_to_markdown_with_html2text(get_html_text_from_url(entry.url))
            except Exception as e:
                print(f"处理{filename}的全文时候发生异常，源地址可以已经删除，直接跳过，请手动处理！")

            md = dump_markdown_with_frontmatter(
                webpage.__dict__,
                content,
            )
            output_content_to_file_path(
                output,
                filename,
                md,
                "md")

            print(f"Done: {entry.title}")
            result_index += f'\n- [[~{filename}|{entry.title}]]'
        older_than = str(entries[-1].timestamp)
    # 容错处理
    print("导出index\n", result_index)

@eto.command()
@click.option('--output', '-o', required=True, help='输出目录')
def v2ex(output):
    result_index = "";
    page = 1
    while True:
        id_list = get_fav_list_topic_id_page(page)
        if not id_list or len(id_list) == 0:
            break
        page = page + 1
        for id in id_list:
            result = get_v2ex_topic_info(id)
            if not result:
                continue
            topic = result.result
            filename = get_clean_filename(str(id) + '-' + topic.title)
            file_path = os.path.join(output, f"~{filename}.md")
            if os.path.exists(file_path):
                print(f"已存在: {filename}.md，同步结束")
                print("导出index\n", result_index)
                return
            created_time = datetime.fromtimestamp(topic.created).strftime('%Y-%m-%dT%H:%M:%S%z')
            modified_time = datetime.fromtimestamp(topic.last_modified).strftime('%Y-%m-%dT%H:%M:%S%z')
            webpage = WebPage(
                comments=True,
                draft=True,
                title=topic.title,
                source=topic.url,
                created=created_time,
                modified=modified_time,
                type="archive-web"
            )
            md = dump_markdown_with_frontmatter(
                webpage.__dict__,
                topic.content
            )
            output_content_to_file_path(
                output,
                filename,
                md,
                "md")

            print(f"Done: {topic.title}")
            result_index += f'\n- [[~{filename}|{topic.title}]]'
    print("导出完成index\n", result_index)

@eto.command()
@click.option('--collection', '-c', required=True, help='收藏夹')
@click.option('--output', '-o', required=True, help='输出目录')
def zhihu(collection, output):
    result_index = "";
    offset = 0
    limit = 20

    while True:
        page = get_collection_page(collection, offset, limit)
        # 处理当前页的数据
        for c in page.data:
            content = c.content
            article = ''
            title = ''
            id = content.id
            if isinstance(content.content, list):
                # 想法
                title = c.content.content[0]['title']
                article = content.content[0]['content']
            else:
                title = content.title or content.question.title
                article = content.content

            filename = get_clean_filename( id + "-" + title)
            file_path = os.path.join(output, f"~{filename}.md")
            if os.path.exists(file_path):
                print(f"已存在: {filename}.md，同步结束")
                print("导出index\n", result_index)
                return

            created_time = datetime.fromtimestamp(content.created_time).strftime('%Y-%m-%dT%H:%M:%S%z')
            modified_time = datetime.fromtimestamp(content.updated_time).strftime('%Y-%m-%dT%H:%M:%S%z')
            webpage = WebPage(
                comments=True,
                draft=True,
                title=title,
                source=content.url,
                created=created_time,
                modified=modified_time,
                type="archive-web"
            )
            md = dump_markdown_with_frontmatter(
                webpage.__dict__,
                html_to_markdown_with_html2text(article)
            )
            output_content_to_file_path(
                output,
                filename,
                md,
                "md")

            print(f"Done: {title}")
            result_index += f'\n- [[~{filename}|{title}]]'


        if page.data is None or len(page.data) == 0:
            break
        offset += limit

    print(f"输出index:\n{result_index}")

def sync_all_collection_under_subject_type(subject_type: int, output_dir: str, template_path: str, force: bool = False):
    collection_type_list = CollectionType.all()
    for collection_type in collection_type_list:
        print("正在处理: ", collection_type)
        bangumi_export(
            subject_type=subject_type,
            collection_type=collection_type.value,
            output_dir=output_dir,
            template_path=template_path,
            force=force
        )
        print("处理完成: ", collection_type)

if __name__ == '__main__':
    eto()

    # v2ex("output/v2ex")
    # zhihu(908297073, "output/zhihu")
    # write_bangumi_data_from_id(
    #     subject_id=334105,
    #     collection_type=2,
    #     output_dir="output/bangumi",
    #     template_path="config/bangumi_template.md"
    # )
    # sync_all_collection_under_subject_type(
    #     subject_type=SubjectType.ANIME.value,
    #     output_dir="output/bangumi",
    #     template_path="config/bangumi_template.md"
    # )
    # qireader('tag-xxx', "output/qireader")





#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-06
@Links : https://github.com/bGZo
"""

READ_LATER = "https://www.qireader.com/api/streams/"
"""
target-url: https://www.qireader.com/api/streams/{tagId}?articleOrder=0&count=25&id={tagId}&unreadOnly=false&olderThan=1764313764608411573

:param id
:param olderThan
------------------------------------------------------------------------------
{
  "result": {
    "id": "tag-xxx",
    "entries": [
      {
        "id": "GWplALGn3z4Vebvn",
        "isSaved": true,
        "sourceEntryId": "GWplALGn3z4Vebvn",
        "origin": {
          "feedId": "0rmREjBzpAQJdNnD"
        },
        "title": "具透 | 当一个视频下载脚本被迫变成半个浏览器；Android 侧载保住了一半",
        "summary": "yt-dlp开始依赖外部JavaScript运行时@PlatyHsu：yt-dlp是开源社区非常有名的视频下载工具，也是youtube-dl停止更新之后，少数保持活跃和可用的选项。除了在终端直接使用外 ...查看全文本文为会员文章，出自《单篇文章》，订阅后可阅读全文。",
        "url": "https://sspai.com/prime/story/inside-release-notes-251119",
        "publishedAt": 1763545494000,
        "crawledAt": 1763549787159,
        "timestamp": "1763974116059279295",
        "attachments": [],
        "tagIds": [
          "xxx"
        ]
      }
    ],
    "hasMore": true
  }
}
"""

FULL_TEXT = "https://nettools3.oxyry.com/text"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-07
@Links : https://github.com/bGZo
"""
from qireader.cilent import QiReaderClient


def get_html_text_from_url(url) -> str:
    client = QiReaderClient()
    response = client.session.get(client.api_endpoints.FULL_TEXT,  params={
        'keep-classes': 1,
        'url': url,
    })
    print(f"获取{url}响应成功")
    return response.json()['content']

if __name__ == '__main__':
    test_url = "https://www.hecaitou.com/2023/06/go-through-the-window-to-get-a-haircut.html"
    html_text = get_html_text_from_url(test_url)
    print(html_text)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-12-06
@Links : https://github.com/bGZo
"""
import os

import requests

from demo import (api_endpoints)

class DemoClient:
    def __init__(self):
        self.token = os.getenv("DEMO_TOKEN")
        self.cookie = os.getenv("DEMO_COOKIE")

        if not self.token:
            raise ValueError("DEMO_TOKEN environment variable is not set.")
        if not self.cookie:
            raise ValueError("DEMO_COOKIE environment variable is not set.")

        self.session = requests.Session()
        self.session.headers.update({
            "Authorization": f"Bearer {self.token}",
            "Cookie": f"{self.cookie}",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:144.0) Gecko/20100101 Firefox/144.0",
            "Referer": "https://www.example.com"
        })
        self.api_endpoints = api_endpoints

